#!/bin/sh

rm -f /var/bin/evocamd
rm -f /var/bin/evocamd_cam.sh

if [ "`cat /var/etc/SifTeam/tmp/cam_active.sif`" = "evocamd" ]; then
	rm -f /var/etc/SifTeam/tmp/cam_active.sif
fi

rm -f /var/etc/SifTeam/tmp/settable.cam/evocamd_cam.sh

rm -f /var/uninstall/evocamd_delfile.sh

exit 0
